@@ -27,6 +27,10 @@ static void
 about_cb (GtkWidget *widget, gpointer data)
 {
 	static GtkWidget *about = NULL;
+	GdkPixbuf  	 *pixbuf;
+	GError     	 *error = NULL;
+	gchar      	 *file;
+	
 	gchar *authors[] = {
 		"George Lebl <jirka@5z.com>",
 		"Bastien Nocera <hadess@hadess.net> (fixes)",
@@ -44,14 +48,28 @@ about_cb (GtkWidget *widget, gpointer data)
 		gdk_window_raise(about->window);
 		return;
 	}
-	about = gnome_about_new(_("The GNOME Calculator"), VERSION,
+	
+	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-calc2.png", FALSE, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (file, &error);
+	
+	if (error) {
+		g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+		g_error_free (error);
+	}
+	g_free (file);
+	
+	about = gnome_about_new(_("GNOME Calculator"), VERSION,
 				"(C) 1998 the Free Software Foundation",
 				_("Simple double precision calculator similiar "
 				  "to xcalc"),
 				(const char **)authors,
 				(const char **)documenters,
 				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-				NULL);
+				pixbuf);
+	if (pixbuf) {
+		gdk_pixbuf_unref (pixbuf);
+	}			
+				
 	gtk_signal_connect(GTK_OBJECT(about), "destroy",
 			   GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about);
 	gtk_widget_show (about);
@@ -113,7 +131,7 @@ static GnomeUIInfo edit_menu[] = {
 };
 
 static GnomeUIInfo help_menu[] = {
-	GNOMEUIINFO_HELP("gcalc"),
+	GNOMEUIINFO_HELP("gnome-calculator"),
 	GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb,NULL),
 	GNOMEUIINFO_END
 };
@@ -174,7 +192,8 @@ main(int argc, char *argv[])
 	textdomain(GETTEXT_PACKAGE);
 
 	gnome_program_init ("gnome-calculator", VERSION, LIBGNOMEUI_MODULE,
-			argc, argv, GNOME_PARAM_POPT_TABLE, options, NULL);
+			argc, argv, GNOME_PARAM_POPT_TABLE, options, 
+			GNOME_PARAM_APP_DATADIR,DATADIR, NULL);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-calc2.png");
 
 	if (analog) {
@@ -184,7 +203,7 @@ main(int argc, char *argv[])
 
         app = gnome_app_new("gnome-calculator", _("GNOME Calculator"));
 	gtk_window_set_wmclass (GTK_WINDOW (app), "gnome-calculator", "gnome-calculator");
-	gtk_window_set_policy (GTK_WINDOW (app), FALSE, TRUE, FALSE);
+	gtk_window_set_resizable (GTK_WINDOW (app), TRUE);
 
         gtk_signal_connect(GTK_OBJECT(app), "delete_event",
 			GTK_SIGNAL_FUNC(quit_cb), NULL);
@@ -220,3 +239,4 @@ main(int argc, char *argv[])
 
 	return 0;
 }
+
