@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.39 2002/04/15 11:53:55 kmaraas Exp $ */
+/* $Id: gdict-app.c,v 1.45 2002/04/26 14:51:47 gman Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -36,10 +36,9 @@
 
 #ifdef HAVE_GNOME_PRINT
 #  include <libgnomeprint/gnome-printer-dialog.h>
-#  include <libgnomeprint/gnome-printer-profile.h>
 #endif /* HAVE_GNOME_PRINT */
 
-#define APPNAME "gdict"
+#define APPNAME "gnome-dictionary"
 
 GtkWidget *gdict_app;
 GtkWidget *gdict_appbar;
@@ -415,7 +414,7 @@ find_cb (GtkMenuItem *menuitem, gpointer user_data)
 {
     if (!defbox->def_cmd)
         return;
-
+    gnome_appbar_pop (GNOME_APPBAR (gdict_appbar));
     gnome_appbar_set_prompt (GNOME_APPBAR (gdict_appbar), _("Find:"), TRUE);
 }
 
@@ -531,11 +530,11 @@ add_atk_relation(GtkWidget *obj1, GtkWidget *obj2, AtkRelationType rel_type)
 
 }
 
-static GnomeUIInfo file_menu_uiinfo[] = {
-    GNOMEUIINFO_ITEM_STOCK (N_("Lookup"),
+static GnomeUIInfo dictionary_menu_uiinfo[] = {
+    GNOMEUIINFO_ITEM_STOCK (N_("_Lookup"),
 			    N_("Lookup word in dictionary"),
 			    lookup_cb, GNOME_STOCK_MENU_SEARCH),
-    GNOMEUIINFO_ITEM_STOCK (N_("Spell"), 
+    GNOMEUIINFO_ITEM_STOCK (N_("_Spell"), 
 			    N_("Check word spelling"), 
 			    spell_cb, GNOME_STOCK_MENU_SPELLCHECK),
 #ifdef HAVE_GNOME_PRINT
@@ -544,7 +543,9 @@ static GnomeUIInfo file_menu_uiinfo[] = {
     GNOMEUIINFO_MENU_PRINT_SETUP_ITEM (print_setup_cb, NULL),
 #endif /* HAVE_GNOME_PRINT */
     GNOMEUIINFO_SEPARATOR,
-    GNOMEUIINFO_MENU_EXIT_ITEM (exit_cb, NULL),
+    GNOMEUIINFO_ITEM_STOCK (N_("_Quit"),
+			    N_("Quit dictionary"),
+			    exit_cb, GTK_STOCK_QUIT),
     GNOMEUIINFO_END
 };
 
@@ -580,7 +581,9 @@ static GnomeUIInfo help_menu_uiinfo[] = {
 };
 
 static GnomeUIInfo menubar_uiinfo[] = {
-    GNOMEUIINFO_MENU_FILE_TREE (file_menu_uiinfo),
+    { GNOME_APP_UI_SUBTREE_STOCK, N_("_Dictionary"), NULL, 
+      dictionary_menu_uiinfo, NULL, NULL, (GnomeUIPixmapType) 0, 
+      NULL, 0, (GdkModifierType) 0, NULL },
     GNOMEUIINFO_MENU_EDIT_TREE (edit_menu_uiinfo),
     GNOMEUIINFO_MENU_HELP_TREE (help_menu_uiinfo),
     GNOMEUIINFO_END
@@ -621,7 +624,7 @@ GtkWidget *gdict_app_create (gboolean applet) {
     gtk_widget_show (dock);
     
     if (applet)  /* quick hack */
-        memcpy (&file_menu_uiinfo[EXIT_FILE_MENU_ITEM],
+        memcpy (&dictionary_menu_uiinfo[EXIT_FILE_MENU_ITEM],
 		&applet_close_item, sizeof(GnomeUIInfo));
 
     gnome_app_create_menus (GNOME_APP (gdict_app), menubar_uiinfo);
@@ -669,6 +672,7 @@ GtkWidget *gdict_app_create (gboolean applet) {
         gail_loaded = TRUE;
         add_atk_namedesc(GTK_WIDGET(word_label), _("Word"), _("Word"));
         add_atk_namedesc(gnome_word_entry, _("Word Entry"), _("Enter a Word or select one from the list below"));
+        add_atk_namedesc(word_entry, _("Word Entry"), NULL);
         add_atk_relation(gnome_word_entry, GTK_WIDGET(word_label), ATK_RELATION_LABELLED_BY);
         add_atk_namedesc(GTK_WIDGET(button), NULL, _("Look Up for a Word"));
     }
@@ -700,10 +704,10 @@ GtkWidget *gdict_app_create (gboolean applet) {
 
     gtk_box_pack_start (GTK_BOX (vbox), scrolled, TRUE, TRUE, 0);
 
-    gdict_appbar = gnome_appbar_new (TRUE, TRUE, GNOME_PREFERENCES_ALWAYS);
+    gdict_appbar = gnome_appbar_new (FALSE, TRUE, GNOME_PREFERENCES_ALWAYS);
     gtk_widget_show (gdict_appbar);
     gnome_app_set_statusbar (GNOME_APP (gdict_app), gdict_appbar);
-   
+
     if (!applet)
       gtk_signal_connect (GTK_OBJECT (gdict_app), "delete_event",
                           GTK_SIGNAL_FUNC (gtk_main_quit), NULL);
