@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.30 2002/02/25 04:06:18 hadess Exp $ */
+/* $Id: gdict-applet.c,v 1.32 2002/04/25 12:40:48 gman Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -194,7 +194,8 @@ help_cb (BonoboUIComponent *uic,
           gpointer           user_data,
           const gchar       *verbname)
 {
-
+	GError *error = NULL;
+        gnome_help_display("gnome-dictionary",NULL,&error);
 }
 
 static void
@@ -238,10 +239,10 @@ spell_cb (BonoboUIComponent *uic,
 }
 
 static const BonoboUIVerb gdict_applet_menu_verbs [] = {
-        BONOBO_UI_VERB ("about", about_cb),
-        BONOBO_UI_VERB ("help", help_cb),
-        BONOBO_UI_VERB ("prefs", prefs_cb),
 	BONOBO_UI_VERB ("def win", show_hide_defbox_cb),
+        BONOBO_UI_VERB ("prefs", prefs_cb),
+        BONOBO_UI_VERB ("help", help_cb),
+        BONOBO_UI_VERB ("about", about_cb),
        
         BONOBO_UI_VERB_END
 };
@@ -260,9 +261,11 @@ gdict_applet_new (PanelApplet *parent_applet)
 	applet->pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/gdict.png", NULL);
 	
 	applet->button_widget = gtk_button_new ();
-	
-	gtk_box_pack_start (GTK_BOX (hbox), applet->button_widget, FALSE, FALSE, 2);
 
+        if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible (applet->button_widget)))          
+        add_atk_namedesc (GTK_WIDGET (applet->button_widget), _("Dictionary Applet"), NULL);
+
+	gtk_box_pack_start (GTK_BOX (hbox), applet->button_widget, FALSE, FALSE, 2);
 	gtk_widget_show_all (hbox);
 
 #if 0	  	
@@ -328,7 +331,7 @@ gdict_applet_factory (PanelApplet *applet,
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_GDictApplet_Factory",
 			     PANEL_TYPE_APPLET,
-                             "Dictionary",
+                             "gnome-dictionary",
                              "0",
                              gdict_applet_factory,
                              NULL)
