@@ -291,8 +291,10 @@ main (int argc, char *argv[])
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 
-	gnome_init_with_popt_table ("gfloppy", VERSION, argc, argv,
-				    gfloppy_opts, 0, NULL);
+	gnome_program_init ("gfloppy",VERSION, LIBGNOMEUI_MODULE,
+			    argc, argv, GNOME_PARAM_POPT_TABLE, gfloppy_opts,
+                            GNOME_PARAM_POPT_FLAGS, 0,
+                            GNOME_PARAM_APP_DATADIR,DATADIR,NULL);
 	/* FIXME: get the right icon */
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/mc/i-floppy.png");
 	init_commands ();
@@ -333,10 +335,7 @@ main (int argc, char *argv[])
 			break;
 
 		if (button == GFLOPPY_HELP) {
-#if 0
-			GnomeHelpMenuEntry ref = {"gfloppy", "index.html"};
-			gnome_help_display (NULL, &ref);
-#endif
+			gnome_help_display ("gfloppy", NULL, NULL);
 			continue;
 		}
 		density_option = glade_xml_get_widget (xml, "density_option");
