@@ -1,6 +1,7 @@
 /* meat-grinder, maker of tarballs */
 
 #include <config.h>
+#include <gtk/gtk.h>
 #include <gnome.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
@@ -14,18 +15,28 @@ static GtkWidget *icon_list = NULL;
 static GtkWidget *status_label = NULL;
 static GtkWidget *compress_button = NULL;
 static GHashTable *file_ht = NULL;
-static int number_of_files = 0;
-static int number_of_dirs = 0;
-static char *file_icon = NULL;
-static char *folder_icon = NULL;
-static char *compress_icon = NULL;
-static char *tar_prog = NULL;
-static char *filename = NULL;
+static gint number_of_files = 0;
+static gint number_of_dirs = 0;
+static gchar *file_icon = NULL;
+static gchar *folder_icon = NULL;
+static gchar *compress_icon = NULL;
+static gchar *tar_prog = NULL;
+static gchar *sh_prog = NULL;
+static gchar *gzip_prog = NULL;
+static gchar *tarstr = NULL;
+static gchar *filestr = NULL;
+static gchar *gzipstr = NULL;
+static gchar *filename = NULL;
 static pid_t temporary_pid = 0;
-static char *temporary_file = NULL;
+static gchar *temporary_file = NULL;
+struct poptOption options;
 
-#define ERRDLG(error) gnome_dialog_run_and_close (GNOME_DIALOG (gnome_error_dialog_parented (error, GTK_WINDOW (app))))
-#define ERRDLGP(error,parent) gnome_dialog_run_and_close (GNOME_DIALOG (gnome_error_dialog_parented (error, GTK_WINDOW (parent))))
+static GtkWidget *create_archive_widget=NULL;
+static GtkWidget *remove_widget=NULL;
+static GtkWidget *clear_widget=NULL;
+
+#define ERRDLG(error) gtk_message_dialog_new (GTK_WINDOW(app), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, error);
+#define ERRDLGP(error,parent) gtk_message_dialog_new (GTK_WINDOW(parent), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, error);
 
 static GtkTargetEntry drop_targets [] = {
   { "text/uri-list", 0, 0 }
@@ -46,9 +57,9 @@ enum {
 
 typedef struct _File File;
 struct _File {
-	int type;
-	char *name;
-	char *base_name;
+	gint type;
+	gchar *name;
+	gchar *base_name;
 };
 
 static void
@@ -60,39 +71,54 @@ free_file (File *f)
 	g_free (f);
 }
 
+static void 
+cleanup_tmpstr (void)
+{
+	g_free(tarstr);
+	tarstr = NULL;
+	g_free(filestr);
+	filestr = NULL;
+	g_free(gzipstr);
+	gzipstr = NULL;
+}
+
 static char *
 make_temp_dir (void)
 {
 	char *name = NULL;
-	char *gname;
 	do {
 		if (name != NULL)
-			free (name);
-		name = tempnam (NULL, "gmg");
+			g_free (name);
+		name = g_strdup_printf ("/tmp/gnome-meat-grinder-%d",
+					rand ());
 	} while (mkdir (name, 0755) < 0);
 
-	gname = g_strdup (name);
-	free (name);
-	return gname;
+	return name;
 }
 
 static gboolean
 query_dialog (const gchar *msg)
 {
-	int ret;
+	gint response;
 	GtkWidget *req;
 
-	req = gnome_message_box_new (msg,
-				     GNOME_MESSAGE_BOX_QUESTION,
-				     GNOME_STOCK_BUTTON_YES,
-				     GNOME_STOCK_BUTTON_NO,
-				     NULL);
+	req = gtk_message_dialog_new (GTK_WINDOW (app),
+				       GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+				       GTK_MESSAGE_QUESTION,
+				       GTK_BUTTONS_NONE,
+				       msg);
+	
+	gtk_dialog_add_buttons (GTK_DIALOG (req),
+				GTK_STOCK_NO, GTK_RESPONSE_NO,
+				GTK_STOCK_YES, GTK_RESPONSE_YES,
+				NULL);
+	
 
-	gtk_window_set_modal (GTK_WINDOW (req), TRUE);
+	response = gtk_dialog_run (GTK_DIALOG (req));
 
-	ret = gnome_dialog_run (GNOME_DIALOG (req));
+	gtk_widget_destroy(req);
 
-	if (ret == 0)
+	if (response == GTK_RESPONSE_YES)
 		return TRUE;
 	else /* this includes -1 which is "destroyed" */
 		return FALSE;
@@ -102,8 +128,8 @@ static void
 update_status (void)
 {
 	if (number_of_files > 0 || number_of_dirs > 0) {
-		char *msg;
-		msg = g_strdup_printf (_("Number of files: %d\nNuber of folders: %d"),
+		gchar *msg;
+		msg = g_strdup_printf (_("Number of files: %d\nNumber of folders: %d"),
 				       number_of_files, number_of_dirs);
 		gtk_label_set_text (GTK_LABEL (status_label), msg);
 		g_free (msg);
@@ -116,7 +142,7 @@ update_status (void)
 
 /* removes icon, positions should not be trusted after this */
 static void
-remove_pos (int pos)
+remove_pos (gint pos)
 {
 	File *f;
 
@@ -134,15 +160,17 @@ remove_pos (int pos)
 
 	if (number_of_files + number_of_dirs <= 0) {
 		gtk_widget_set_sensitive (compress_button, FALSE);
+		gtk_widget_set_sensitive (create_archive_widget, FALSE);
+		gtk_widget_set_sensitive (clear_widget, FALSE);
 	}
 
 	update_status ();
 }
 
 struct argv_adder {
-	char *link_dir;
-	char **argv;
-	int pos;
+	gchar *link_dir;
+	gchar **argv;
+	gint pos;
 };
 
 static void
@@ -150,9 +178,9 @@ make_argv_fe (gpointer key, gpointer value, gpointer user_data)
 {
 	File *f = value;
 	struct argv_adder *argv_adder = user_data;
-	char *file = g_concat_dir_and_file (argv_adder->link_dir, f->base_name);
+	gchar *file = g_build_filename ((argv_adder->link_dir), (f->base_name), NULL);
 
-	argv_adder->argv[argv_adder->pos ++] = f->base_name;
+	argv_adder->argv[argv_adder->pos ++] = g_strconcat ("\"", f->base_name, "\"", NULL);
 
 	/* FIXME: catch errors */
 	symlink (f->name, file);
@@ -162,8 +190,8 @@ static void
 whack_links_fe (gpointer key, gpointer value, gpointer user_data)
 {
 	File *f = value;
-	char *link_dir = user_data;
-	char *file = g_concat_dir_and_file (link_dir, f->base_name);
+	gchar *link_dir = user_data;
+	gchar *file = g_build_filename ((link_dir), (f->base_name), NULL);
 
 	unlink (file);
 	g_free (file);
@@ -178,7 +206,7 @@ setup_busy (GtkWidget *w, gboolean busy)
 		/* Change cursor to busy */
 		cursor = gdk_cursor_new (GDK_WATCH);
 		gdk_window_set_cursor (w->window, cursor);
-		gdk_cursor_destroy (cursor);
+		gdk_cursor_unref (cursor);
 	} else {
 		gdk_window_set_cursor (w->window, NULL);
 	}
@@ -187,27 +215,46 @@ setup_busy (GtkWidget *w, gboolean busy)
 }
 
 static gboolean
-create_archive (const char *fname,
-		const char *dir,
+create_archive (const gchar *fname,
+		const gchar *dir,
 		gboolean gui_errors)
 {
 	gboolean status = TRUE;
 	pid_t pid;
 	struct argv_adder argv_adder;
+	gchar *tmpfname = NULL;
 
 	if (dir == NULL)
 		argv_adder.link_dir = make_temp_dir ();
 	else
-		argv_adder.link_dir = (char *)dir;
+		argv_adder.link_dir = (gchar *)dir;
 
-	argv_adder.argv = g_new (char *, number_of_files + number_of_dirs + 4);
-	argv_adder.argv[number_of_files + number_of_dirs + 3] = NULL;
-	argv_adder.argv[0] = tar_prog;
-	argv_adder.argv[1] = "-chzf";
-	argv_adder.argv[2] = (char *)fname;
-	argv_adder.pos = 3;
+	/* Added code for appending .tar.gz to archive file */
+	tmpfname = g_strstr_len ((gchar *)fname, strlen((gchar *)fname), ".tar.gz");
+	if (tmpfname == NULL)
+		tmpfname = g_strstr_len ((gchar *)fname, strlen((gchar *)fname), ".tgz");
+	if (tmpfname != NULL) {
+		if (!((g_ascii_strcasecmp(tmpfname, ".tar.gz") == 0) || (g_ascii_strcasecmp(tmpfname, ".tgz") == 0)))
+			fname = g_strconcat ((gchar *)fname, ".tar.gz", NULL);
+	} else {
+		fname = g_strconcat ((gchar *)fname, ".tar.gz", NULL);
+	}
 
+        /* Since tar -z option is not available in Solaris, doing tar & gzip */
+
+	argv_adder.argv = g_new (gchar *, number_of_files + number_of_dirs + 4);
+	argv_adder.pos = 0;
 	g_hash_table_foreach (file_ht, make_argv_fe, &argv_adder);
+	argv_adder.argv[argv_adder.pos ++] = NULL;
+
+	tarstr = g_strconcat(tar_prog, " -chf - ", NULL);
+	filestr = g_strjoinv(" ", argv_adder.argv);
+	gzipstr = g_strconcat(" | ", gzip_prog, " - > ", (gchar *)fname, NULL);
+
+	argv_adder.argv[0] = sh_prog;
+	argv_adder.argv[1] = "-c";
+	argv_adder.argv[2] = g_strconcat(tarstr, filestr, gzipstr, NULL);	
+	argv_adder.argv[3] = NULL;
 
 	/* FIXME: get error output, check for errors, etc... */
 
@@ -224,8 +271,9 @@ create_archive (const char *fname,
 		umask (022);
 		/* FIXME: handler errors */
 		chdir (argv_adder.link_dir);
-		execv (tar_prog, argv_adder.argv);
+		execv (sh_prog, argv_adder.argv);
 		fprintf (stderr, _("Cannot run tar/gtar"));
+		cleanup_tmpstr ();
 		_exit (1);
 	}
 
@@ -243,15 +291,15 @@ create_archive (const char *fname,
 	}
 
 	g_free (argv_adder.argv);
-
+	cleanup_tmpstr ();
 	return status;
 }
 
 static void
 start_temporary (void)
 {
-	char *dir;
-	char *file = NULL;
+	gchar *dir;
+	gchar *file = NULL;
 
 	if (temporary_file != NULL) {
 		if (access (temporary_file, F_OK) == 0)
@@ -262,7 +310,7 @@ start_temporary (void)
 		 * this file is missing, we let nautilus have it and hope
 		 * he chokes on it */
 
-		dir = g_dirname (temporary_file);
+		dir = g_path_get_dirname (temporary_file);
 		rmdir (dir);
 		g_free (dir);
 
@@ -276,7 +324,7 @@ start_temporary (void)
 
 	/* make a temporary dirname */
 	dir = make_temp_dir ();
-	file = g_concat_dir_and_file (dir, _("Archive.tar.gz"));
+	file = g_build_filename ((dir), (_("Archive.tar.gz")), NULL);
 
 	temporary_pid = fork ();
 
@@ -309,7 +357,7 @@ start_temporary (void)
 static gboolean
 ensure_temporary (void)
 {
-	int status;
+	gint status;
 
 	start_temporary ();
 
@@ -338,7 +386,7 @@ ensure_temporary (void)
 static void
 cleanup_temporary (void)
 {
-	char *file = temporary_file;
+	gchar *file = temporary_file;
 	pid_t pid = temporary_pid;
 
 	temporary_file = NULL;
@@ -350,11 +398,11 @@ cleanup_temporary (void)
 	}
 	
 	if (file != NULL) {
-		char *dir;
+		gchar *dir;
 
 		unlink (file);
 
-		dir = g_dirname (file);
+		dir = g_path_get_dirname (file);
 		rmdir (dir);
 		g_free (dir);
 	}
@@ -366,6 +414,10 @@ static void
 about_cb (GtkWidget *widget, gpointer data)
 {
 	static GtkWidget *about = NULL;
+	GdkPixbuf	 *pixbuf;
+	GError		 *error = NULL;
+	gchar		 *file;
+	
 	gchar *authors[] = {
 		"George Lebl <jirka@5z.com>",
 		NULL
@@ -374,23 +426,39 @@ about_cb (GtkWidget *widget, gpointer data)
 		NULL
 	};
 	/* Translator credits */
-	gchar *translator_credits = _("");
+	gchar *translator_credits = _("translator_credits");
 
 	if (about != NULL) {
 		gtk_widget_show_now (about);
 		gdk_window_raise (about->window);
 		return;
 	}
-	about = gnome_about_new (_("The GNOME Archive Generator"), VERSION,
+	
+	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
+			"document-icons/gnome-compressed.png", FALSE, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (file, &error);
+	
+	if (error) {
+		g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+		g_error_free (error);
+	}
+	g_free (file);
+	
+	about = gnome_about_new (_("GNOME Archive Generator"), VERSION,
 				 "(C) 2001 George Lebl",
 				 _("Drag files in to make archives"),
-				 (const char **)authors,
-				 (const char **)documenters,
-				 (const char *)translator_credits,
-				 NULL);
-	gtk_signal_connect (GTK_OBJECT (about), "destroy",
-			    GTK_SIGNAL_FUNC (gtk_widget_destroyed),
-			    &about);
+				 (const gchar **)authors,
+				 (const gchar **)documenters,
+				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				 pixbuf);
+				 
+	if (pixbuf) {
+		gdk_pixbuf_unref (pixbuf);
+	}			 
+	
+	g_signal_connect (G_OBJECT (about), "destroy",
+			  G_CALLBACK (gtk_widget_destroyed),
+			  &about);
 	gtk_widget_show (about);
 }
 
@@ -426,9 +494,30 @@ clear_cb (GtkWidget *w, gpointer data)
 	number_of_files = number_of_dirs = 0;
 	gnome_icon_list_clear (GNOME_ICON_LIST (icon_list));
 	gtk_widget_set_sensitive (compress_button, FALSE);
+	gtk_widget_set_sensitive (create_archive_widget, FALSE);
+	gtk_widget_set_sensitive (remove_widget, FALSE);
+	gtk_widget_set_sensitive (clear_widget, FALSE);
 	update_status ();
 }
 
+static void
+icon_select_cb (GnomeIconList *iconlist,
+		gint arg1,
+		GdkEvent *event,
+		gpointer user_data)
+{
+	gtk_widget_set_sensitive (remove_widget, TRUE);
+}
+
+static void
+icon_unselect_cb (GnomeIconList *iconlist,
+		  gint arg1,
+		  GdkEvent *event,
+		  gpointer user_data) 
+{
+	gtk_widget_set_sensitive (remove_widget, FALSE);
+}
+
 static void
 remove_cb (GtkWidget *w, gpointer data)
 {
@@ -436,11 +525,17 @@ remove_cb (GtkWidget *w, gpointer data)
 	
 	list = gnome_icon_list_get_selection(GNOME_ICON_LIST (icon_list));
 	while (list != NULL) {
-		int pos = GPOINTER_TO_INT (list->data);
+		gint pos = GPOINTER_TO_INT (list->data);
 		remove_pos (pos);
 		list = gnome_icon_list_get_selection
 			(GNOME_ICON_LIST (icon_list));
 	}
+
+	if (number_of_files + number_of_dirs <= 0) {
+		gtk_widget_set_sensitive (compress_button, FALSE);
+		gtk_widget_set_sensitive (create_archive_widget, FALSE);
+		gtk_widget_set_sensitive (clear_widget, FALSE);
+	}
 }
 
 static void
@@ -490,14 +585,14 @@ archive_cb (GtkWidget *w, gpointer data)
 	if (filename != NULL)
 		gtk_file_selection_set_filename (fsel, filename);
 
-	gtk_signal_connect (GTK_OBJECT (fsel->ok_button), "clicked",
-			    GTK_SIGNAL_FUNC (save_ok), fsel);
-	gtk_signal_connect_object
-		(GTK_OBJECT (fsel->cancel_button), "clicked",
-		 GTK_SIGNAL_FUNC (gtk_widget_destroy), 
-		 GTK_OBJECT (fsel));
+	g_signal_connect (G_OBJECT (fsel->ok_button), "clicked",
+			  G_CALLBACK (save_ok), fsel);
+	g_signal_connect_swapped
+		(G_OBJECT (fsel->cancel_button), "clicked",
+		 G_CALLBACK (gtk_widget_destroy), 
+		 fsel);
 
-	gtk_window_position (GTK_WINDOW (fsel), GTK_WIN_POS_MOUSE);
+	gtk_window_set_position (GTK_WINDOW (fsel), GTK_WIN_POS_MOUSE);
 
 	gtk_window_set_transient_for (GTK_WINDOW (fsel),
 				      GTK_WINDOW (app));
@@ -506,16 +601,16 @@ archive_cb (GtkWidget *w, gpointer data)
 }
 
 static void
-add_file (const char *file)
+add_file (const gchar *file)
 {
 	struct stat s;
 	File *f, *oldf;
-	int type;
-	const char *icon;
-	int pos;
-	int i;
-	const char *base_name;
-	char *fullname;
+	gint type;
+	const gchar *icon;
+	gint pos;
+	gint i;
+	const gchar *base_name;
+	gchar *fullname;
 
 	if (file == NULL ||
 	    file[0] == '\0')
@@ -530,14 +625,14 @@ add_file (const char *file)
 	}
 
 	if (strcmp (fullname, "/") != 0)
-		base_name = g_basename (fullname);
+		base_name = g_path_get_basename (fullname);
 	else
 		base_name = "/";
 
 	oldf = g_hash_table_lookup (file_ht, base_name);
 	i = 1;
 	while (oldf != NULL) {
-		char *temp;
+		gchar *temp;
 		if (strcmp (oldf->name, fullname) == 0) {
 			g_free (fullname);
 			return;
@@ -577,6 +672,8 @@ add_file (const char *file)
 	}
 
 	gtk_widget_set_sensitive (compress_button, TRUE);
+	gtk_widget_set_sensitive (create_archive_widget, TRUE);
+	gtk_widget_set_sensitive (clear_widget, TRUE);
 
 	f = g_new0 (File, 1);
 	f->type = type;
@@ -633,14 +730,14 @@ add_cb (GtkWidget *w, gpointer data)
 	if (filename != NULL)
 		gtk_file_selection_set_filename (fsel, filename);
 
-	gtk_signal_connect (GTK_OBJECT (fsel->ok_button), "clicked",
-			    GTK_SIGNAL_FUNC (add_ok), fsel);
-	gtk_signal_connect_object
-		(GTK_OBJECT (fsel->cancel_button), "clicked",
-		 GTK_SIGNAL_FUNC (gtk_widget_destroy), 
-		 GTK_OBJECT (fsel));
+	g_signal_connect (G_OBJECT (fsel->ok_button), "clicked",
+			  G_CALLBACK (add_ok), fsel);
+	g_signal_connect_swapped
+		(G_OBJECT (fsel->cancel_button), "clicked",
+		 G_CALLBACK (gtk_widget_destroy), 
+		 fsel);
 
-	gtk_window_position (GTK_WINDOW (fsel), GTK_WIN_POS_MOUSE);
+	gtk_window_set_position (GTK_WINDOW (fsel), GTK_WIN_POS_MOUSE);
 
 	gtk_window_set_transient_for (GTK_WINDOW (fsel),
 				      GTK_WINDOW (app));
@@ -660,8 +757,8 @@ drag_data_received (GtkWidget          *widget,
 {
 	if (data->length >= 0 &&
 	    data->format == 8) {
-		int i;
-		char **files = g_strsplit ((char *)data->data, "\r\n", -1);
+		gint i;
+		gchar **files = g_strsplit ((gchar *)data->data, "\r\n", -1);
 		for (i = 0; files != NULL && files[i] != NULL; i++) {
 			/* FIXME: EVIL!!!! */
 			if (strncmp (files[i], "file:", strlen ("file:")) == 0)
@@ -682,7 +779,7 @@ drag_data_get (GtkWidget          *widget,
 	       guint               time,
 	       gpointer            data)
 {
-	char *string;
+	gchar *string;
 
 	if ( ! ensure_temporary ()) {
 		/*FIXME: cancel the drag*/
@@ -699,11 +796,11 @@ drag_data_get (GtkWidget          *widget,
 /* Menus */
 static GnomeUIInfo file_menu[] = {
 	GNOMEUIINFO_ITEM_NONE
-		(N_("Add file or folder..."),
+		(N_("_Add file or folder..."),
 		 N_("Add a file or folder to the archive"),
 		 add_cb),
 	GNOMEUIINFO_ITEM_NONE
-		(N_("Create archive..."),
+		(N_("_Create archive..."),
 		 N_("Create a new archive from the items"),
 		 archive_cb),
 	GNOMEUIINFO_SEPARATOR,
@@ -712,7 +809,7 @@ static GnomeUIInfo file_menu[] = {
 };
 
 static GnomeUIInfo edit_menu[] = {
-	GNOMEUIINFO_ITEM_NONE (N_("Remove"),
+	GNOMEUIINFO_ITEM_NONE (N_("_Remove"),
 			       N_("Remove the selected item(s)"),
 			       remove_cb),
 	GNOMEUIINFO_MENU_CLEAR_ITEM (clear_cb, NULL),
@@ -744,15 +841,17 @@ init_gui (void)
 
 	tips = gtk_tooltips_new ();
 
-        app = gnome_app_new ("meat-grinder",
+        app = gnome_app_new ("archive-generator",
 			     _("GNOME Archive Generator"));
 	gtk_window_set_wmclass (GTK_WINDOW (app),
-				"meat-grinder",
-				"meat-grinder");
-	gtk_window_set_policy (GTK_WINDOW (app), FALSE, TRUE, FALSE);
+				"archive-generator",
+				"archive-generator");
+	gtk_window_set_resizable (GTK_WINDOW (app), TRUE);
 
-        gtk_signal_connect (GTK_OBJECT (app), "destroy",
-			    GTK_SIGNAL_FUNC (quit_cb), NULL);
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/document-icons/gnome-compressed.png");
+
+        g_signal_connect (G_OBJECT (app), "delete_event",
+			  G_CALLBACK (quit_cb), NULL);
 
 	/*set up the menu*/
         gnome_app_create_menus (GNOME_APP (app), grinder_menu);
@@ -761,7 +860,7 @@ init_gui (void)
 	gtk_widget_show (vbox);
 
 	sw = gtk_scrolled_window_new (NULL, NULL);
-	gtk_widget_set_usize (sw, 250, 150);
+	gtk_widget_set_size_request (sw, 250, 150);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
@@ -771,6 +870,13 @@ init_gui (void)
 	icon_list = gnome_icon_list_new (/*evil*/66, NULL, 0);
 	gnome_icon_list_set_selection_mode  (GNOME_ICON_LIST (icon_list),
 					     GTK_SELECTION_MULTIPLE);
+
+	g_signal_connect (G_OBJECT (icon_list), "select_icon",
+			  G_CALLBACK (icon_select_cb), NULL);	
+
+	g_signal_connect (G_OBJECT (icon_list), "unselect_icon",
+			  G_CALLBACK (icon_unselect_cb), NULL);	
+
 	gtk_widget_show (icon_list);
 	gtk_container_add (GTK_CONTAINER (sw), icon_list);
 
@@ -797,8 +903,8 @@ init_gui (void)
 	gtk_widget_show (w);
 	gtk_container_add (GTK_CONTAINER (compress_button), w);
 	gtk_box_pack_start (GTK_BOX (hbox), compress_button, FALSE, FALSE, 0);
-	gtk_signal_connect (GTK_OBJECT (compress_button), "clicked",
-			    GTK_SIGNAL_FUNC (archive_cb), NULL);
+	g_signal_connect (G_OBJECT (compress_button), "clicked",
+			  G_CALLBACK (archive_cb), NULL);
 	gtk_tooltips_set_tip (tips, compress_button,
 			      _("Drag this button to the destination where you "
 				"want the archive to be created or press it to "
@@ -806,6 +912,9 @@ init_gui (void)
 			      NULL);
 
 	gtk_widget_set_sensitive (compress_button, FALSE);
+	gtk_widget_set_sensitive (file_menu[1].widget, FALSE);
+	gtk_widget_set_sensitive (edit_menu[0].widget, FALSE);
+	gtk_widget_set_sensitive (edit_menu[1].widget, FALSE);
 
 	/* setup dnd */
 	gtk_drag_source_set (compress_button,
@@ -813,11 +922,10 @@ init_gui (void)
 			     drag_targets, n_drag_targets,
 			     GDK_ACTION_COPY);
 	/* just in case some wanker like nautilus took our image */
-	gtk_signal_connect (GTK_OBJECT (compress_button), "drag_begin",
-			    GTK_SIGNAL_FUNC (start_temporary), NULL);
-	gtk_signal_connect (GTK_OBJECT (compress_button), "drag_data_get",
-			    GTK_SIGNAL_FUNC (drag_data_get), NULL);
-
+	g_signal_connect (G_OBJECT (compress_button), "drag_begin",
+			  G_CALLBACK (start_temporary), NULL);
+	g_signal_connect (G_OBJECT (compress_button), "drag_data_get",
+			  G_CALLBACK (drag_data_get), NULL);
 
 	status_label = gtk_label_new ("");
 	gtk_label_set_justify (GTK_LABEL (status_label), GTK_JUSTIFY_LEFT);
@@ -825,15 +933,15 @@ init_gui (void)
 	gtk_box_pack_start (GTK_BOX (hbox), status_label, FALSE, FALSE, 0);
 	update_status ();
 
-	gtk_container_border_width (GTK_CONTAINER (vbox), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 
 	/* setup dnd */
 	gtk_drag_dest_set (app,
 			   GTK_DEST_DEFAULT_ALL,
 			   drop_targets, n_drop_targets,
 			   GDK_ACTION_LINK);
-	gtk_signal_connect (GTK_OBJECT (app), "drag_data_received",
-			    GTK_SIGNAL_FUNC (drag_data_received), NULL);
+	g_signal_connect (G_OBJECT (app), "drag_data_received",
+			  G_CALLBACK (drag_data_received), NULL);
 
 	gnome_app_set_contents (GNOME_APP (app), vbox);
 
@@ -841,7 +949,7 @@ init_gui (void)
 }
 
 static void
-got_signal (int sig)
+got_signal (gint sig)
 {
 	cleanup_temporary ();
 	
@@ -850,48 +958,79 @@ got_signal (int sig)
 	kill (getpid (), sig);
 }
 
-int
-main (int argc, char *argv [])
+static gint
+save_session (GnomeClient *client, gint phase,
+ 	      GnomeRestartStyle save_style, gint shutdown,
+ 	      GnomeInteractStyle interact_style, gint fast,
+ 	      gpointer client_data)
 {
-	int i;
+ 	gchar *argv[] = { NULL };
+ 
+ 	argv[0] = (gchar *) client_data;
+ 	gnome_client_set_clone_command (client, 1, argv);
+ 	gnome_client_set_restart_command (client, 1, argv);
+ 
+ 	return TRUE;
+}
+ 
+static gint
+die (GnomeClient *client, gpointer client_data)
+{
+	gtk_main_quit ();
+}
+
+gint
+main (gint argc, gchar *argv [])
+{
+	gint i;
 	poptContext ctx;
-	const char **files;
+	const gchar **files;
+	GnomeClient *client;
 	
 	/* Initialize the i18n stuff */
 	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 
-	gnome_init_with_popt_table ("meat-grinder", VERSION,
-				    argc, argv, NULL, 0, &ctx);
+	gnome_program_init ("meat-grinder", VERSION, LIBGNOMEUI_MODULE,
+				    argc, argv, GNOME_PARAM_POPT_TABLE,
+				    &options,GNOME_PARAM_APP_DATADIR,DATADIR,NULL);
+
+	client = gnome_master_client ();
+
+	g_signal_connect (client, "save_yourself",
+			  G_CALLBACK (save_session), (gpointer)argv[0]);
+
+	g_signal_connect (client, "die", G_CALLBACK (die), NULL);
+
 	/* no icon yet */
 	/*gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-meat-grinder.png");*/
 
-	file_icon = gnome_pixmap_file ("mc/i-regular.png");
+	file_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "mc/i-regular.png", TRUE, NULL);
 	if (file_icon == NULL)
-		file_icon = gnome_pixmap_file ("nautilus/i-regular.png");
+		file_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "nautilus/i-regular.png", TRUE, NULL);
 	if (file_icon == NULL)
-		file_icon = gnome_pixmap_file ("nautilus/gnome/i-regular.png");
+		file_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "nautilus/gnome/i-regular.png", TRUE, NULL);
 	if (file_icon == NULL)
-		file_icon = gnome_pixmap_file ("gnome-file.png");
+		file_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-file.png", TRUE, NULL);
 	if (file_icon == NULL)
-		file_icon = gnome_pixmap_file ("gnome-unknown.png");
+		file_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-unknown.png", TRUE, NULL);
 
-	folder_icon = gnome_pixmap_file ("gnome-folder.png");
+	folder_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-folder.png", TRUE, NULL);
 	if (folder_icon == NULL)
-		folder_icon = gnome_pixmap_file ("nautilus/gnome-folder.png");
+		folder_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "nautilus/gnome-folder.png", TRUE, NULL);
 	if (folder_icon == NULL)
-		folder_icon = gnome_pixmap_file ("nautilus/gnome/gnome/gnome-folder.png");
+		folder_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "nautilus/gnome/gnome/gnome-folder.png", TRUE, NULL);
 	if (folder_icon == NULL)
-		folder_icon = gnome_pixmap_file ("mc/i-directory.png");
+		folder_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "mc/i-directory.png", TRUE, NULL);
 	if (folder_icon == NULL)
-		folder_icon = gnome_pixmap_file ("gnome-unknown.png");
+		folder_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-unknown.png", TRUE, NULL);
 
-	compress_icon = gnome_pixmap_file ("gnome-compressed.png");
+	compress_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-compressed.png", TRUE, NULL);
 	if (compress_icon == NULL)
-		compress_icon = gnome_pixmap_file ("nautilus/gnome-compressed.png");
+		compress_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "nautilus/gnome-compressed.png", TRUE, NULL);
 	if (compress_icon == NULL)
-		compress_icon = gnome_pixmap_file ("mc/gnome-compressed.png");
+		compress_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "mc/gnome-compressed.png", TRUE, NULL);
 
 	if (folder_icon == NULL || file_icon == NULL) {
 		ERRDLG (_("Cannot find proper icons anywhere!"));
@@ -906,11 +1045,29 @@ main (int argc, char *argv [])
 			  "This is the program used for creating archives."));
 		exit (1);
 	}
+	sh_prog = g_find_program_in_path ("sh");
+	if (sh_prog == NULL) {
+		g_print("Cannot find the shell (sh) program! Aborting");
+		exit (1);
+	}
+
+	gzip_prog = g_find_program_in_path ("gzip");
+	if (gzip_prog == NULL) {
+		g_print("Cannot find the compression (gzip) program!\n"
+			 "This is the program used for compressing archives.\n");
+		exit (1);
+	}
+
+	ctx = poptGetContext (PACKAGE, argc, (const char **) argv, &options, 0);
 
 	files = poptGetArgs (ctx);
 
 	init_gui ();
 
+	create_archive_widget = file_menu[1].widget;
+	remove_widget = edit_menu[0].widget;
+	clear_widget = edit_menu[1].widget;
+
 	file_ht = g_hash_table_new (g_str_hash, g_str_equal);
 
 	gnome_icon_list_freeze (GNOME_ICON_LIST (icon_list));
@@ -919,8 +1076,8 @@ main (int argc, char *argv [])
 		if (files[i][0] == '/') {
 			add_file (files[i]);
 		} else {
-			char *curdir = g_get_current_dir ();
-			char *file = g_concat_dir_and_file (curdir, files[i]);
+			gchar *curdir = g_get_current_dir ();
+			gchar *file = g_build_filename ((curdir), (files[i]), NULL);
 			add_file (file);
 			g_free (file);
 			g_free (curdir);
@@ -935,6 +1092,10 @@ main (int argc, char *argv [])
 	gtk_main ();
 
 	cleanup_temporary ();
+
+	g_free(tar_prog);
+	g_free(sh_prog);
+	g_free(gzip_prog);
 	
 	return 0;
 }
